@@ -14,11 +14,12 @@
 # limitations under the License.
 #
 # Authors:
+#   Baudouin Raoult - ECMWF - https://ecmwf.int
 #   Alessandro Amici - B-Open - https://bopen.eu
 #
 
 from __future__ import absolute_import, division, print_function, unicode_literals
-from builtins import str  # noqa
+from builtins import str
 
 import datetime
 import logging
@@ -36,34 +37,6 @@ GRIB_STEP_UNITS_TO_SECONDS = [
     60, 3600, 86400, None, None, None, None, None, None, None,
     10800, 21600, 43200, 1, 900, 1800,
 ]
-
-COORD_ATTRS = {
-    'time': {
-        'units': 'seconds since 1970-01-01T00:00:00+00:00', 'calendar': 'proleptic_gregorian',
-        'standard_name': 'forecast_reference_time', 'long_name': 'initial time of forecast',
-    },
-    'step': {
-        'units': 'hours',
-        'standard_name': 'forecast_period', 'long_name': 'time since forecast_reference_time',
-    },
-    'valid_time': {
-        'units': 'seconds since 1970-01-01T00:00:00+00:00', 'calendar': 'proleptic_gregorian',
-        'standard_name': 'time', 'long_name': 'time',
-    },
-    'latitude': {
-        'units': 'degrees_north',
-        'standard_name': 'latitude', 'long_name': 'latitude',
-    },
-    'longitude': {
-        'units': 'degrees_east',
-        'standard_name': 'longitude', 'long_name': 'longitude',
-    },
-    'air_pressure': {
-        'units': 'hPa', 'positive': 'down',
-        'standard_name': 'air_pressure', 'long_name': 'pressure',
-    },
-}
-
 DEFAULT_EPOCH = datetime.datetime(1970, 1, 1)
 
 
@@ -91,7 +64,9 @@ def from_grib_date_time(message, date_key='dataDate', time_key='dataTime', epoch
     return int((data_datetime - epoch).total_seconds())
 
 
-def to_grib_date_time(message, time_ns, date_key='dataDate', time_key='dataTime', epoch=DEFAULT_EPOCH):
+def to_grib_date_time(
+        message, time_ns, date_key='dataDate', time_key='dataTime', epoch=DEFAULT_EPOCH,
+):
     # type: (T.MutableMapping, np.datetime64, str, str, datetime.datetime) -> None
     time_s = int(time_ns) * 1e-9
     time = epoch + datetime.timedelta(seconds=time_s)
@@ -111,12 +86,14 @@ def to_grib_step(message, step_ns, step_unit=1, step_key='endStep', step_unit_ke
     # step_seconds = np.timedelta64(step, 's').astype(int)
     step_s = int(step_ns) * 1e-9
     to_seconds = GRIB_STEP_UNITS_TO_SECONDS[step_unit]
+    if to_seconds is None:
+        raise ValueError("unsupported stepUnit %r" % step_unit)
     message[step_key] = step_s / to_seconds
     message[step_unit_key] = step_unit
 
 
 def build_valid_time(time, step):
-    # type: (np.ndarray, np.ndarray) -> T.Tuple[T.Sequence[int], np.ndarray]
+    # type: (np.ndarray, np.ndarray) -> T.Tuple[T.Tuple[str, ...], np.ndarray]
     """
     Return dimensions and data of the valid_time corresponding to the given ``time`` and ``step``.
     The data is seconds from the same epoch as ``time`` and may have one or two dimensions.
@@ -127,7 +104,7 @@ def build_valid_time(time, step):
     step_s = step * 3600
     if len(time.shape) == 0 and len(step.shape) == 0:
         data = time + step_s
-        dims = ()
+        dims = ()  # type: T.Tuple[str, ...]
     elif len(time.shape) > 0 and len(step.shape) == 0:
         data = time + step_s
         dims = ('time',)
@@ -140,29 +117,9 @@ def build_valid_time(time, step):
     return dims, data
 
 
-def from_grib_pl_level(message, level_key='topLevel'):
-    # type: (T.Mapping, str) -> float
-    type_of_level = message['typeOfLevel']
-    if type_of_level == 'isobaricInhPa':
-        coord = float(message[level_key])
-    elif type_of_level == 'isobaricInPa':
-        coord = message[level_key] / 100.
-    else:
-        raise ValueError("Unsupported value of typeOfLevel: %r" % type_of_level)
-    return coord
-
-
-def to_grib_pl_level(message, coord, level_key='topLevel'):
-    # type: (T.MutableMapping, float, str) -> None
-    # ecCodes accepts floats in hPa and correctly encodes them to int in isobaricInPa if needed
-    message['typeOfLevel'] = 'isobaricInhPa'
-    message[level_key] = coord
-
-
 COMPUTED_KEYS = {
     'time': (from_grib_date_time, to_grib_date_time),
     'step': (from_grib_step, to_grib_step),
-    'air_pressure': (from_grib_pl_level, to_grib_pl_level),
 }
 
 
