@@ -22,13 +22,13 @@ from builtins import list, object, set, str
 
 import collections
 import logging
-import pkg_resources
 import typing as T
 import warnings
 
 import attr
 import numpy as np
 
+from . import __version__
 from . import cfmessage
 from . import eccodes
 from . import messages
@@ -52,19 +52,37 @@ DATA_ATTRIBUTES_KEYS = [
 
 GRID_TYPE_MAP = {
     'regular_ll': [
-        'Ni', 'iDirectionIncrementInDegrees', 'iScansNegatively',
+        'Nx', 'iDirectionIncrementInDegrees', 'iScansNegatively',
         'longitudeOfFirstGridPointInDegrees', 'longitudeOfLastGridPointInDegrees',
-        'Nj', 'jDirectionIncrementInDegrees', 'jPointsAreConsecutive', 'jScansPositively',
+        'Ny', 'jDirectionIncrementInDegrees', 'jPointsAreConsecutive', 'jScansPositively',
         'latitudeOfFirstGridPointInDegrees', 'latitudeOfLastGridPointInDegrees',
     ],
+    'rotated_ll': [
+        'Nx', 'Ny', 'angleOfRotationInDegrees',
+        'iDirectionIncrementInDegrees', 'iScansNegatively',
+        'jDirectionIncrementInDegrees', 'jPointsAreConsecutive', 'jScansPositively',
+        'latitudeOfFirstGridPointInDegrees', 'latitudeOfLastGridPointInDegrees',
+        'latitudeOfSouthernPoleInDegrees',
+        'longitudeOfFirstGridPointInDegrees', 'longitudeOfLastGridPointInDegrees',
+        'longitudeOfSouthernPoleInDegrees',
+    ],
     'reduced_ll': [
-        'Nj', 'jDirectionIncrementInDegrees', 'jPointsAreConsecutive', 'jScansPositively',
+        'Ny', 'jDirectionIncrementInDegrees', 'jPointsAreConsecutive', 'jScansPositively',
         'latitudeOfFirstGridPointInDegrees', 'latitudeOfLastGridPointInDegrees',
     ],
     'regular_gg': [
-        'Ni', 'iDirectionIncrementInDegrees', 'iScansNegatively',
+        'Nx', 'iDirectionIncrementInDegrees', 'iScansNegatively',
         'longitudeOfFirstGridPointInDegrees', 'longitudeOfLastGridPointInDegrees',
-        'N', 'Nj',
+        'N', 'Ny',
+    ],
+    'rotated_gg': [
+        'Nx', 'Ny', 'angleOfRotationInDegrees',
+        'iDirectionIncrementInDegrees', 'iScansNegatively',
+        'jPointsAreConsecutive', 'jScansPositively',
+        'latitudeOfFirstGridPointInDegrees', 'latitudeOfLastGridPointInDegrees',
+        'latitudeOfSouthernPoleInDegrees',
+        'longitudeOfFirstGridPointInDegrees', 'longitudeOfLastGridPointInDegrees',
+        'longitudeOfSouthernPoleInDegrees', 'N',
     ],
     'lambert': [
         'LaDInDegrees', 'LoVInDegrees', 'iScansNegatively',
@@ -116,6 +134,10 @@ COORD_ATTRS = {
         'units': '1', 'positive': 'down', 'long_name': 'hybrid level',
         'standard_name': 'atmosphere_hybrid_sigma_pressure_coordinate',
     },
+    'heightAboveGround': {
+        'units': 'm', 'positive': 'up', 'long_name': 'height above the surface',
+        'standard_name': 'height',
+    },
     'number': {
         'units': '1',
         'standard_name': 'realization', 'long_name': 'ensemble member numerical id',
@@ -226,9 +248,10 @@ class OnDiskArray(object):
         return array
 
 
-GRID_TYPES_DIMENSION_COORDS = ('regular_ll', 'regular_gg')
-GRID_TYPES_2D_NON_DIMENSION_COORDS = ('lambert', 'albers', 'polar_stereographic')
-GRID_TYPES_1D_NON_DIMENSION_COORDS = ('reduced_ll', 'reduced_gg')
+GRID_TYPES_DIMENSION_COORDS = ['regular_ll', 'regular_gg']
+GRID_TYPES_2D_NON_DIMENSION_COORDS = [
+    'rotated_ll', 'rotated_gg', 'lambert', 'albers', 'polar_stereographic',
+]
 
 
 def build_geography_coordinates(
@@ -242,7 +265,7 @@ def build_geography_coordinates(
     grid_type = index.getone('gridType')
     if 'geography' in encode_cf and grid_type in GRID_TYPES_DIMENSION_COORDS:
         geo_dims = ('latitude', 'longitude')  # type: T.Tuple[str, ...]
-        geo_shape = (index.getone('Nj'), index.getone('Ni'))  # type: T.Tuple[int, ...]
+        geo_shape = (index.getone('Ny'), index.getone('Nx'))  # type: T.Tuple[int, ...]
         latitudes = np.array(first['distinctLatitudes'])
         geo_coord_vars['latitude'] = Variable(
             dimensions=('latitude',), data=latitudes, attributes=COORD_ATTRS['latitude'].copy(),
@@ -265,7 +288,7 @@ def build_geography_coordinates(
                 dimensions=('y', 'x'), data=np.array(first['longitudes']).reshape(geo_shape),
                 attributes=COORD_ATTRS['longitude'],
             )
-        except KeyError:
+        except KeyError:  # pragma: no cover
             log.warning('No latitudes/longitudes provided by ecCodes for gridType=%r', grid_type)
     else:
         geo_dims = ('values',)
@@ -282,13 +305,16 @@ def build_geography_coordinates(
                 dimensions=('values',), data=np.array(longitude),
                 attributes=COORD_ATTRS['longitude'],
             )
-        except KeyError:
+        except KeyError:  # pragma: no cover
             log.warning('No latitudes/longitudes provided by ecCodes for gridType=%r', grid_type)
     return geo_dims, geo_shape, geo_coord_vars
 
 
 def encode_cf_first(data_var_attrs, encode_cf=('parameter', 'time')):
     coords_map = ENSEMBLE_KEYS[:]
+    param_id = data_var_attrs.get('GRIB_paramId', 'undef')
+    data_var_attrs['long_name'] = 'original GRIB paramId: %s' % param_id
+    data_var_attrs['units'] = '1'
     if 'parameter' in encode_cf:
         if 'GRIB_cfName' in data_var_attrs:
             data_var_attrs['standard_name'] = data_var_attrs['GRIB_cfName']
@@ -322,7 +348,11 @@ def build_variable_components(index, encode_cf=(), filter_by_keys={}, log=LOG):
                 'GRIB_typeOfLevel' in data_var_attrs:
             coord_name = data_var_attrs['GRIB_typeOfLevel']
             coord_name_key_map[coord_name] = coord_key
-        attributes = COORD_ATTRS.get(coord_name, {}).copy()
+        attributes = {
+            'long_name': 'original GRIB coordinate for key: %s(%s)' % (coord_key, coord_name),
+            'units': '1',
+        }
+        attributes.update(COORD_ATTRS.get(coord_name, {}).copy())
         data = np.array(sorted(values, reverse=attributes.get('stored_direction') == 'decreasing'))
         dimensions = (coord_name,)
         if len(values) == 1:
@@ -353,7 +383,7 @@ def build_variable_components(index, encode_cf=(), filter_by_keys={}, log=LOG):
 
     if 'time' in coord_vars and 'time' in encode_cf:
         # add the 'valid_time' secondary coordinate
-        step_data = coord_vars['step'].data if 'data' in coord_vars else np.array(0.)
+        step_data = coord_vars['step'].data if 'step' in coord_vars else np.array(0.)
         dims, time_data = cfmessage.build_valid_time(
             coord_vars['time'].data, step_data,
         )
@@ -378,7 +408,7 @@ def dict_merge(master, update):
 
 
 def build_dataset_components(
-        stream, indexpath='{path}.{short_hash}.idx', filter_by_keys={}, errors='ignore',
+        stream, indexpath='{path}.{short_hash}.idx', filter_by_keys={}, errors='strict',
         encode_cf=('parameter', 'time', 'geography', 'vertical'), log=LOG,
 ):
     filter_by_keys = dict(filter_by_keys)
@@ -404,7 +434,6 @@ def build_dataset_components(
             else:
                 raise
     attributes = enforce_unique_attributes(index, GLOBAL_ATTRIBUTES_KEYS, filter_by_keys)
-    cfgrib_ver = pkg_resources.get_distribution("cfgrib").version
     eccodes_ver = eccodes.codes_get_api_version()
     encoding = {
         'source': stream.path,
@@ -412,8 +441,10 @@ def build_dataset_components(
         'encode_cf': encode_cf,
     }
     open_text = ', '.join('%s=%r' % it for it in encoding.items())
+    attributes['Conventions'] = 'CF-1.7'
+    attributes['institution'] = attributes['GRIB_centreDescription']
     attributes['history'] = 'GRIB to CDM+CF via ' \
-        'cfgrib-%s/ecCodes-%s with %s' % (cfgrib_ver, eccodes_ver, open_text)
+        'cfgrib-%s/ecCodes-%s with %s' % (__version__, eccodes_ver, open_text)
     return dimensions, variables, attributes, encoding
 
 
