@@ -192,6 +192,17 @@ int codes_write_message(codes_handle* h,const char* file,const char* mode);
  */
 codes_handle* codes_grib_handle_new_from_samples (codes_context* c, const char* sample_name);
 
+/**
+ *  Create a handle from a BUFR message contained in a samples directory.
+ *  The message is copied at the creation of the handle
+ *
+ * @param c           : the context from which the handle will be created (NULL for default context)
+ * @param sample_name : the name of the sample file (without the .tmpl extension)
+ * @return            the new handle, NULL if the resource is invalid or a problem is encountered
+ */
+codes_handle* codes_bufr_handle_new_from_samples (codes_context* c, const char* sample_name);
+
+
 /**
 *  Clone an existing handle using the context of the original handle,
 *  The message is copied and reparsed
@@ -254,6 +265,28 @@ int codes_get_size(codes_handle* h, const char* key,size_t *size);
 */
 int codes_get_length(codes_handle* h, const char* key,size_t *length);
 
+/**
+*  Get a long value from a key, if several keys of the same name are present, the last one is returned
+*  @see  codes_set_long
+*
+* @param h           : the handle to get the data from
+* @param key         : the key to be searched
+* @param value       : the address of a long where the data will be retrieved
+* @return            0 if OK, integer value on error
+*/
+int codes_get_long(codes_handle* h, const char* key, long*   value  );
+
+/**
+*  Get a double value from a key, if several keys of the same name are present, the last one is returned
+*  @see  codes_set_double
+*
+* @param h           : the handle to get the data from
+* @param key         : the key to be searched
+* @param value       : the address of a double where the data will be retrieved
+* @return            0 if OK, integer value on error
+*/
+int codes_get_double(codes_handle* h, const char* key, double* value                             );
+
 /**
 *  Get a string value from a key, if several keys of the same name are present, the last one is returned
 * @see  codes_set_string
