@@ -378,7 +378,7 @@ def codes_get_length(handle, key):
 _codes_get_bytes = check_return(lib.codes_get_bytes)
 
 
-def codes_get_bytes_array(handle, key, size=None):
+def codes_get_bytes_array(handle, key, size):
     # type: (cffi.FFI.CData, bytes, int) -> T.List[int]
     """
     Get unsigned chars array values from a key.
@@ -387,8 +387,6 @@ def codes_get_bytes_array(handle, key, size=None):
 
     :rtype: List(int)
     """
-    if size is None:
-        size = codes_get_size(handle, key)
     values = ffi.new('unsigned char[]', size)
     size_p = ffi.new('size_t *', size)
     _codes_get_bytes(handle, key, values, size_p)
@@ -398,7 +396,7 @@ def codes_get_bytes_array(handle, key, size=None):
 _codes_get_long_array = check_return(lib.codes_get_long_array)
 
 
-def codes_get_long_array(handle, key, size=None):
+def codes_get_long_array(handle, key, size):
     # type: (cffi.FFI.CData, bytes, int) -> T.List[int]
     """
     Get long array values from a key.
@@ -407,8 +405,6 @@ def codes_get_long_array(handle, key, size=None):
 
     :rtype: List(int)
     """
-    if size is None:
-        size = codes_get_size(handle, key)
     values = ffi.new('long[]', size)
     size_p = ffi.new('size_t *', size)
     _codes_get_long_array(handle, key, values, size_p)
@@ -418,7 +414,7 @@ def codes_get_long_array(handle, key, size=None):
 _codes_get_double_array = check_return(lib.codes_get_double_array)
 
 
-def codes_get_double_array(handle, key, size=None):
+def codes_get_double_array(handle, key, size):
     # type: (cffi.FFI.CData, bytes, int) -> T.List[float]
     """
     Get double array values from a key.
@@ -427,8 +423,6 @@ def codes_get_double_array(handle, key, size=None):
 
     :rtype: T.List(float)
     """
-    if size is None:
-        size = codes_get_size(handle, key)
     values = ffi.new('double[]', size)
     size_p = ffi.new('size_t *', size)
     _codes_get_double_array(handle, key, values, size_p)
@@ -438,7 +432,7 @@ def codes_get_double_array(handle, key, size=None):
 _codes_get_string_array = check_return(lib.codes_get_string_array)
 
 
-def codes_get_string_array(handle, key, size=None, length=None):
+def codes_get_string_array(handle, key, size, length=None):
     # type: (cffi.FFI.CData, bytes, int, int) -> T.List[bytes]
     """
     Get string array values from a key.
@@ -447,8 +441,6 @@ def codes_get_string_array(handle, key, size=None, length=None):
 
     :rtype: T.List[bytes]
     """
-    if size is None:
-        size = codes_get_size(handle, key)
     if length is None:
         length = codes_get_length(handle, key)
     values_keepalive = [ffi.new('char[]', length) for _ in range(size)]
@@ -477,6 +469,22 @@ def codes_get_bytes(handle, key):
     return values[-1]
 
 
+def codes_get_long(handle, key):
+    # type: (cffi.FFI.CData, bytes) -> int
+    value = ffi.new('long *')
+    _codes_get_long = check_return(lib.codes_get_long)
+    _codes_get_long(handle, key, value)
+    return value[0]
+
+
+def codes_get_double(handle, key):
+    # type: (cffi.FFI.CData, bytes) -> int
+    value = ffi.new('double *')
+    _codes_get_long = check_return(lib.codes_get_double)
+    _codes_get_long(handle, key, value)
+    return value[0]
+
+
 def codes_get_string(handle, key, length=None):
     # type: (cffi.FFI.CData, bytes, int) -> bytes
     """
@@ -494,8 +502,8 @@ def codes_get_string(handle, key, length=None):
         length = codes_get_length(handle, key)
     values = ffi.new('char[]', length)
     length_p = ffi.new('size_t *', length)
-    codes_get_string = check_return(lib.codes_get_string)
-    codes_get_string(handle, key, values, length_p)
+    _codes_get_string = check_return(lib.codes_get_string)
+    _codes_get_string(handle, key, values, length_p)
     return ffi.string(values, length_p[0])
 
 
@@ -513,15 +521,17 @@ def codes_get_array(handle, key, key_type=None,  size=None, length=None, log=LOG
     # type: (cffi.FFI.CData, bytes, int, int, int, logging.Logger) -> T.Any
     if key_type is None:
         key_type = codes_get_native_type(handle, key)
+    if size is None:
+        size = codes_get_size(handle, key)
 
     if key_type == CODES_TYPE_LONG:
-        return codes_get_long_array(handle, key, size=size)
+        return codes_get_long_array(handle, key, size)
     elif key_type == CODES_TYPE_DOUBLE:
-        return codes_get_double_array(handle, key, size=size)
+        return codes_get_double_array(handle, key, size)
     elif key_type == CODES_TYPE_STRING:
-        return codes_get_string_array(handle, key, size=size, length=length)
+        return codes_get_string_array(handle, key, size, length=length)
     elif key_type == CODES_TYPE_BYTES:
-        return codes_get_bytes_array(handle, key, size=size)
+        return codes_get_bytes_array(handle, key, size)
     else:
         log.warning("Unknown GRIB key type: %r", key_type)
 
@@ -532,11 +542,9 @@ def codes_get(handle, key, key_type=None, length=None, log=LOG):
         key_type = codes_get_native_type(handle, key)
 
     if key_type == CODES_TYPE_LONG:
-        values = codes_get_long_array(handle, key, size=1)  # type: T.Sequence[T.Any]
-        return values[0]
+        return codes_get_long(handle, key)
     elif key_type == CODES_TYPE_DOUBLE:
-        values = codes_get_double_array(handle, key, size=1)
-        return values[0]
+        return codes_get_double(handle, key)
     elif key_type == CODES_TYPE_STRING:
         return codes_get_string(handle, key, length=length)
     elif key_type == CODES_TYPE_BYTES:
@@ -585,9 +593,12 @@ def codes_get_api_version():
 
 def codes_new_from_samples(samplename, product_kind=CODES_PRODUCT_GRIB):
     # type: (bytes, int) -> cffi.FFI.CData
-    if product_kind != CODES_PRODUCT_GRIB:
-        raise NotImplementedError("Support implemented only for GRIB.")
-    handle = lib.codes_grib_handle_new_from_samples(ffi.NULL, samplename)
+    if product_kind == CODES_PRODUCT_GRIB:
+        handle = lib.codes_grib_handle_new_from_samples(ffi.NULL, samplename)
+    elif product_kind == CODES_PRODUCT_BUFR:
+        handle = lib.codes_bufr_handle_new_from_samples(ffi.NULL, samplename)
+    else:
+        raise NotImplementedError("product kind not supported: %r" % product_kind)
     if handle == ffi.NULL:
         raise ValueError("sample not found: %r" % samplename)
     return handle
