@@ -52,16 +52,16 @@ class Message(collections.MutableMapping):
     errors = attr.attrib(default='ignore', validator=attr.validators.in_(['ignore', 'strict']))
 
     @classmethod
-    def from_file(cls, file, offset=None, **kwargs):
-        # type: (T.IO[bytes], int, T.Any) -> Message
+    def from_file(cls, file, offset=None, product_kind=eccodes.CODES_PRODUCT_GRIB, **kwargs):
+        # type: (T.IO[bytes], int, int, T.Any) -> Message
         if offset is not None:
             file.seek(offset)
-        codes_id = eccodes.codes_handle_new_from_file(file)
+        codes_id = eccodes.codes_handle_new_from_file(file, product_kind)
         return cls(codes_id=codes_id, **kwargs)
 
     @classmethod
-    def from_sample_name(cls, sample_name, **kwargs):
-        codes_id = eccodes.codes_new_from_samples(sample_name.encode('ASCII'))
+    def from_sample_name(cls, sample_name, product_kind=eccodes.CODES_PRODUCT_GRIB, **kwargs):
+        codes_id = eccodes.codes_new_from_samples(sample_name.encode('ASCII'), product_kind)
         return cls(codes_id=codes_id, **kwargs)
 
     @classmethod
@@ -207,10 +207,14 @@ class FileStream(collections.Iterable):
     def __iter__(self):
         # type: () -> T.Generator[Message, None, None]
         with open(self.path, 'rb') as file:
+            valid_grib_message_found = False
             while True:
                 try:
                     yield self.message_from_file(file, errors=self.errors)
+                    valid_grib_message_found = True
                 except EOFError:
+                    if not valid_grib_message_found:
+                        raise EOFError("No valid GRIB message found in file: %r" % self.path)
                     break
                 except Exception:
                     if self.errors == 'ignore':
