@@ -1,6 +1,9 @@
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
+import pytest
+xr = pytest.importorskip('xarray')  # noqa
+
 from cf2cdm import cfunits
 
 
