@@ -29,8 +29,6 @@ def test_Message_read():
 
     assert res1.message_get('non-existent-key', default=1) == 1
 
-    list()
-
     res2 = messages.Message.from_message(res1)
     assert res2.items() == res1.items()
 
@@ -209,3 +207,8 @@ def test_FileStream():
     assert len(leader) > 100
     assert sum(1 for _ in res) == leader['count']
     assert len(res.index(['paramId'])) == 1
+
+    # __file__ is not a GRIB, but contains the "GRIB" string, so it is a very tricky corner case
+    res = messages.FileStream(str(__file__))
+    with pytest.raises(EOFError):
+        res.first()
