@@ -87,6 +87,8 @@ def test_build_data_var_components_encode_cf_geography():
 
 def test_Dataset():
     res = dataset.open_file(TEST_DATA)
+    assert 'Conventions' in res.attributes
+    assert 'institution' in res.attributes
     assert 'history' in res.attributes
     assert res.attributes['GRIB_edition'] == 1
     assert tuple(res.dimensions.keys()) == \
@@ -101,6 +103,8 @@ def test_Dataset_no_encode():
     res = dataset.open_file(
         TEST_DATA, encode_cf=()
     )
+    assert 'Conventions' in res.attributes
+    assert 'institution' in res.attributes
     assert 'history' in res.attributes
     assert res.attributes['GRIB_edition'] == 1
     assert tuple(res.dimensions.keys()) == ('number', 'dataDate', 'dataTime', 'level', 'values')
